package io.agora.adapter;

import android.app.Activity;
import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RelativeLayout;
import android.widget.TextView;

import java.util.List;

import io.agora.model.MessageBean;
import io.agora.rtmtutorial.R;


public class MessageAdapter extends RecyclerView.Adapter<MessageAdapter.MyViewHolder> {

    private List<MessageBean> messageBeanList;
    protected final LayoutInflater inflater;

    public MessageAdapter(Context context, List<MessageBean> messageBeanList) {
        inflater = ((Activity) context).getLayoutInflater();
        this.messageBeanList = messageBeanList;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = inflater.inflate(R.layout.msg_item_layout, parent, false);
        MyViewHolder holder = new MyViewHolder(view);
        return holder;
    }

    @Override
    public void onBindViewHolder(MyViewHolder holder, int position) {
        setupView(holder, position);
    }

    @Override
    public int getItemCount() {
        return messageBeanList.size();
    }


    private void setupView(MyViewHolder holder, int position) {

        MessageBean bean = messageBeanList.get(position);
        if (bean.isBeSelf()) {
            holder.textViewSelfName.setText(bean.getAccount());
            holder.textViewSelfMsg.setText(bean.getMessage());

        } else {
            holder.textViewOtherName.setText(bean.getAccount());
            holder.textViewOtherMsg.setText(bean.getMessage());
            if (bean.getBackground() != 0) {
                holder.textViewOtherName.setBackgroundResource(bean.getBackground());
            }
        }

        holder.layoutRight.setVisibility(bean.isBeSelf() ? View.VISIBLE : View.GONE);
        holder.layoutLeft.setVisibility(bean.isBeSelf() ? View.GONE : View.VISIBLE);
    }

    class MyViewHolder extends RecyclerView.ViewHolder {

        private TextView textViewOtherName;
        private TextView textViewOtherMsg;
        private TextView textViewSelfName;
        private TextView textViewSelfMsg;
        private RelativeLayout layoutLeft;
        private RelativeLayout layoutRight;

        public MyViewHolder(View itemView) {
            super(itemView);

            textViewOtherName = (TextView) itemView.findViewById(R.id.item_name_l);
            textViewOtherMsg = (TextView) itemView.findViewById(R.id.item_msg_l);
            textViewSelfName = (TextView) itemView.findViewById(R.id.item_name_r);
            textViewSelfMsg = (TextView) itemView.findViewById(R.id.item_msg_r);
            layoutLeft = (RelativeLayout) itemView.findViewById(R.id.item_layout_l);
            layoutRight = (RelativeLayout) itemView.findViewById(R.id.item_layout_r);
        }
    }
}
